summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umllistview.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/umllistview.h')
-rw-r--r--umbrello/umbrello/umllistview.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/umbrello/umbrello/umllistview.h b/umbrello/umbrello/umllistview.h
index 3420c1f4..b6bf201c 100644
--- a/umbrello/umbrello/umllistview.h
+++ b/umbrello/umbrello/umllistview.h
@@ -49,10 +49,10 @@ public:
/**
* Constructs the tree view.
*
* @param tqparent The tqparent to this.
* @param name The internal name for this class.
*/
- UMLListView(TQWidget *tqparent,const char *name);
+ UMLListView(TQWidget *parent,const char *name);
/**
* Standard deconstructor.
@@ -106,41 +106,41 @@ public:
* CHECK - This is perhaps redundant since the
* UMLListViewItemData => UMLListViewItem merge.
* Creates a new UMLListViewItem from a UMLListViewItem, if
* tqparent is null the ListView Decides who is going to be the
* tqparent
*/
UMLListViewItem* createItem(UMLListViewItem& Data, IDChangeLog& IDChanges,
- UMLListViewItem* tqparent = 0);
+ UMLListViewItem* parent = 0);
/**
* Find the tqparent folder for a diagram.
* If the currently selected item in the list view is a folder
* then that folder is returned as the tqparent.
*
* @param dt The Diagram_Type of the diagram.
* The type will only be used if there is no currently
* selected item, or if the current item is not a folder.
* In that case the root folder which is suitable for the
* Diagram_Type is returned.
* @return Pointer to the tqparent UMLListViewItem for the diagram.
*/
UMLListViewItem *findFolderForDiagram(Uml::Diagram_Type dt);
/**
* Determine the tqparent ListViewItem given an UMLObject.
*
* @param object Pointer to the UMLObject for which to look up the tqparent.
* @return Pointer to the tqparent UMLListViewItem chosen.
* Returns NULL on error (no tqparent could be determined.)
*/
UMLListViewItem* determineParentItem(UMLObject* object) const;
/**
* Determine the tqparent ListViewItem given a ListView_Type.
* This tqparent is used for creating new UMLListViewItems.
*
* @param lvt The ListView_Type for which to lookup the tqparent.
* @return Pointer to the tqparent UMLListViewItem chosen.
*/
UMLListViewItem* determineParentItem(Uml::ListView_Type lvt) const;
@@ -169,11 +169,11 @@ public:
}
/**
* Adds a new item to the tree of the given type under the given tqparent.
* Method will take care of signalling anyone needed on creation of new item.
* e.g. UMLDoc if an UMLObject is created.
*/
- void addNewItem(UMLListViewItem * tqparent, Uml::ListView_Type type);
+ void addNewItem(UMLListViewItem * parent, Uml::ListView_Type type);
/**
* Find an UMLObject in the listview.
@@ -260,7 +260,7 @@ public:
/**
* Moves an object given is unique ID and listview type to an
* other listview tqparent item.
* Also takes care of the corresponding move in the model.
*/
UMLListViewItem * moveObject(Uml::IDType srcId, Uml::ListView_Type srcType,
@@ -286,7 +286,7 @@ public:
* predefined root views (Root, Logical, UseCase, Component,
* Deployment, EntityRelationship.) Returns the ListView_Type
* of the matching root view; if no match then continues the
* search using the item's tqparent, then grandtqparent, and so forth.
* Returns Uml::lvt_Unknown if no match at all is found.
*/
Uml::ListView_Type rootViewType(UMLListViewItem *item);
@@ -295,7 +295,7 @@ public:
bool loadFromXMI( TQDomElement & element );
- bool loadChildrenFromXMI( UMLListViewItem * tqparent, TQDomElement & element );
+ bool loadChildrenFromXMI( UMLListViewItem * parent, TQDomElement & element );
protected:
UMLListViewItem* m_rv; // root view (home)
@@ -343,9 +343,9 @@ protected:
void loadPixmaps();
/**
* Deletes all child-items of @p tqparent.
*/
- void deleteChildrenOf( TQListViewItem *tqparent );
+ void deleteChildrenOf( TQListViewItem *parent );
/**
* Delete a listview item.
@@ -357,18 +357,18 @@ protected:
/**
* Adds a new operation, attribute or template item to a classifier, identical to
* childObjectAdded(obj) but with an explicit tqparent.
* @param child the child object
* @param tqparent the tqparent object
*/
- void childObjectAdded(UMLClassifierListItem* child, UMLClassifier* tqparent);
+ void childObjectAdded(UMLClassifierListItem* child, UMLClassifier* parent);
/**
* Auxiliary method for moveObject(): Adds the model object at the proper
* new container (package if nested, UMLDoc if at global level), and
* updates the containment relationships in the model.
*/
- void addAtContainer(UMLListViewItem *item, UMLListViewItem *tqparent);
+ void addAtContainer(UMLListViewItem *item, UMLListViewItem *parent);
public slots:
@@ -433,7 +433,7 @@ public slots:
/**
* Something has been dragged and dropped onto the list view
*/
- void slotDropped(TQDropEvent* de, TQListViewItem* tqparent, TQListViewItem* item);
+ void slotDropped(TQDropEvent* de, TQListViewItem* parent, TQListViewItem* item);
/**
* calls updateFolder() on the item to update the icon to open
@@ -49,10 +49,10 @@ public:
* Constructs the tree view.
*
- * @param tqparent The tqparent to this.
+ * @param parent The parent to this.
* @param name The internal name for this class.
*/
@@ -106,41 +106,41 @@ public:
* UMLListViewItemData => UMLListViewItem merge.
* Creates a new UMLListViewItem from a UMLListViewItem, if
- * tqparent is null the ListView Decides who is going to be the
- * tqparent
+ * parent is null the ListView Decides who is going to be the
+ * parent
*/
UMLListViewItem* createItem(UMLListViewItem& Data, IDChangeLog& IDChanges,
@@ -106,41 +106,41 @@ public:
/**
- * Find the tqparent folder for a diagram.
+ * Find the parent folder for a diagram.
* If the currently selected item in the list view is a folder
@@ -106,41 +106,41 @@ public:
* If the currently selected item in the list view is a folder
- * then that folder is returned as the tqparent.
+ * then that folder is returned as the parent.
*
* @param dt The Diagram_Type of the diagram.
@@ -106,41 +106,41 @@ public:
* In that case the root folder which is suitable for the
* Diagram_Type is returned.
- * @return Pointer to the tqparent UMLListViewItem for the diagram.
+ * @return Pointer to the parent UMLListViewItem for the diagram.
*/
UMLListViewItem *findFolderForDiagram(Uml::Diagram_Type dt);
@@ -106,41 +106,41 @@ public:
UMLListViewItem *findFolderForDiagram(Uml::Diagram_Type dt);
/**
- * Determine the tqparent ListViewItem given an UMLObject.
+ * Determine the parent ListViewItem given an UMLObject.
*
@@ -106,41 +106,41 @@ public:
*
- * @param object Pointer to the UMLObject for which to look up the tqparent.
- * @return Pointer to the tqparent UMLListViewItem chosen.
- * Returns NULL on error (no tqparent could be determined.)
+ * @param object Pointer to the UMLObject for which to look up the parent.
+ * @return Pointer to the parent UMLListViewItem chosen.
+ * Returns NULL on error (no parent could be determined.)
*/
UMLListViewItem* determineParentItem(UMLObject* object) const;
@@ -106,41 +106,41 @@ public:
UMLListViewItem* determineParentItem(UMLObject* object) const;
/**
- * Determine the tqparent ListViewItem given a ListView_Type.
- * This tqparent is used for creating new UMLListViewItems.
+ * Determine the parent ListViewItem given a ListView_Type.
+ * This parent is used for creating new UMLListViewItems.
*
@@ -106,41 +106,41 @@ public:
*
- * @param lvt The ListView_Type for which to lookup the tqparent.
- * @return Pointer to the tqparent UMLListViewItem chosen.
+ * @param lvt The ListView_Type for which to lookup the parent.
+ * @return Pointer to the parent UMLListViewItem chosen.
*/
UMLListViewItem* determineParentItem(Uml::ListView_Type lvt) const;
@@ -169,11 +169,11 @@ public:
}
/**
- * Adds a new item to the tree of the given type under the given tqparent.
+ * Adds a new item to the tree of the given type under the given parent.
* Method will take care of signalling anyone needed on creation of new item.
* e.g. UMLDoc if an UMLObject is created.
@@ -260,7 +260,7 @@ public:
/**
* Moves an object given is unique ID and listview type to an
- * other listview tqparent item.
+ * other listview parent item.
* Also takes care of the corresponding move in the model.
*/
@@ -286,7 +286,7 @@ public:
* Deployment, EntityRelationship.) Returns the ListView_Type
* of the matching root view; if no match then continues the
- * search using the item's tqparent, then grandtqparent, and so forth.
+ * search using the item's parent, then grandparent, and so forth.
* Returns Uml::lvt_Unknown if no match at all is found.
*/
@@ -343,9 +343,9 @@ protected:
void loadPixmaps();
/**
- * Deletes all child-items of @p tqparent.
+ * Deletes all child-items of @p parent.
*/
@@ -357,18 +357,18 @@ protected:
/**
* Adds a new operation, attribute or template item to a classifier, identical to
- * childObjectAdded(obj) but with an explicit tqparent.
+ * childObjectAdded(obj) but with an explicit parent.
* @param child the child object
@@ -357,18 +357,18 @@ protected:
* @param child the child object
- * @param tqparent the tqparent object
+ * @param parent the parent object
*/